# Summary

[Introduction](introduction.md)

# User Guide

- [Installation](installation.md)
- [Examples](examples/README.md)
  - [Unit Tests](examples/unit_tests/README.md)
  - [Spheres](examples/spheres/README.md)
- [Smoothing](smoothing/README.md)
  - [Laplace](smoothing/laplace.md)
  - [Hierarchical Laplace](smoothing/laplace_hierarchical.md)
  - [Taubin](smoothing/taubin.md)
  - [Python visualization](smoothing/python_visualization.md)
- [Dualization](dualization/README.md)

# Reference Guide

- [Command Line Interface](cli/README.md)
  - [Convert](cli/convert.md)
  - [Mesh](cli/mesh.md)
  - [Metrics](cli/metrics.md)
  - [Smooth](cli/smooth.md)
- [Analysis](analysis/README.md)
  - [Sphere with Shells](analysis/sphere_with_shells/README.md)
    - [Timing - `automesh`](analysis/sphere_with_shells/timing_automesh.md)
    - [Timing - Sculpt](analysis/sphere_with_shells/timing_sculpt.md)
    - [Simulation](analysis/sphere_with_shells/simulation.md)
    - [Conforming Mesh](analysis/sphere_with_shells/conforming.md)

# Appendices

- [Development](development/README.md)
    - [Python](development/python.md)
    - [Rust](development/rust.md)

-----------

[Contributors](contributors.md)
